@@ -1,15 +1,15 @@
-shiftp <- 
-function (e_ij1, e_ij2, e_i1, e_i2, e_i3, time1, time2, time3,
-          industry.names = NULL, 
-          output.results = TRUE, 
-          plot.results = FALSE, plot.colours = NULL, plot.title = NULL,
-          plot.portfolio = FALSE, ...) {
-  
+shiftp <- function (e_ij1, e_ij2, e_i1, e_i2, e_i3, time1, time2, time3,
+                    industry.names = NULL, 
+                    print.results = TRUE, 
+                    plot.results = FALSE, plot.colours = NULL, plot.title = NULL,
+                    plot.portfolio = FALSE, ...)
+
+{
   shift_i <- shifti (e_ij1, e_ij2, e_i1, e_i2, time1, time2,
                      industry.names = industry.names, 
                      shift.method = "Gerfin",
                      gerfin.shifts = "mean",
-                     output.results = FALSE, 
+                     print.results = FALSE, 
                      plot.results = FALSE, plot.colours = NULL, plot.title = NULL,
                      plot.portfolio = FALSE, ...)
 
@@ -34,6 +34,7 @@ function (e_ij1, e_ij2, e_i1, e_i2, e_i3, time1, time2, time3,
   
   cat ("\n")
   
+  
   results <- list (components = shift_i$components, components.industry = shift_i$components.industry, growth = shift_i$growth, prog = prog, method = shift_i$method)
   
   invisible(results)
